@@ -19,7 +19,7 @@
     Home: https://github.com/gorhill/uBlock
 */
 
-// For background page
+/* globals browser */
 
 'use strict';
 
@@ -181,8 +181,11 @@ vAPI.Tabs = class extends vAPI.Tabs {
             return Array.from(out);
         }
 
+        // https://github.com/uBlockOrigin/uBlock-issues/issues/2063
+        //   Do not interfere with root document
         suspendOneRequest(details) {
             this.suspendedTabIds.add(details.tabId);
+            if ( details.type === 'main_frame' ) { return; }
             return {
                 redirectUrl: vAPI.getURL(`web_accessible_resources/empty?secret=${vAPI.warSecret()}`)
             };
@@ -236,3 +239,20 @@ vAPI.prefetching = (( ) => {
 })();
 
 /******************************************************************************/
+
+vAPI.scriptletsInjector = ((doc, scriptlets) => {
+    let script;
+    try {
+        script = doc.createElement('script');
+        script.appendChild(doc.createTextNode(scriptlets));
+        (doc.head || doc.documentElement).appendChild(script);
+        self.uBO_scriptletsInjected = true;
+    } catch (ex) {
+    }
+    if ( script ) {
+        script.remove();
+        script.textContent = '';
+    }
+}).toString();
+
+/******************************************************************************/
