@@ -19,6 +19,8 @@
     Home: https://github.com/gorhill/uBlock
 */
 
+/* globals browser */
+
 'use strict';
 
 /******************************************************************************/
@@ -80,11 +82,8 @@ const hiddenSettingsDefault = {
     requestJournalProcessPeriod: 1000,
     selfieAfter: 2,
     strictBlockingBypassDuration: 120,
-    suspendTabsUntilReady: 'unset',
     uiPopupConfig: 'unset',
-    uiFlavor: 'unset',
     uiStyles: 'unset',
-    uiTheme: 'unset',
     updateAssetBypassBrowserCache: false,
     userResourcesLocation: 'unset',
 };
@@ -98,6 +97,9 @@ const userSettingsDefault = {
     collapseBlocked: true,
     colorBlindFriendly: false,
     contextMenuEnabled: true,
+    uiAccentCustom: false,
+    uiAccentCustom0: '#aca0f7',
+    uiTheme: 'auto',
     externalLists: '',
     firewallPaneMinimized: true,
     hyperlinkAuditingDisabled: true,
@@ -109,6 +111,7 @@ const userSettingsDefault = {
     prefetchingDisabled: true,
     requestLogMaxEntries: 1000,
     showIconBadge: true,
+    suspendUntilListsAreLoaded: vAPI.Net.canSuspend(),
     tooltipsDisabled: false,
     webrtcIPAddressHidden: false,
 };
@@ -148,7 +151,6 @@ const µBlock = {  // jshint ignore:line
     privacySettingsSupported: vAPI.browserSettings instanceof Object,
     cloudStorageSupported: vAPI.cloud instanceof Object,
     canFilterResponseData: typeof browser.webRequest.filterResponseData === 'function',
-    canInjectScriptletsNow: vAPI.webextFlavor.soup.has('chromium'),
 
     // https://github.com/chrisaljoudi/uBlock/issues/180
     // Whitelist directives need to be loaded once the PSL is available
@@ -174,8 +176,8 @@ const µBlock = {  // jshint ignore:line
 
     // Read-only
     systemSettings: {
-        compiledMagic: 44,  // Increase when compiled format changes
-        selfieMagic: 45,    // Increase when selfie format changes
+        compiledMagic: 50,  // Increase when compiled format changes
+        selfieMagic: 50,    // Increase when selfie format changes
     },
 
     // https://github.com/uBlockOrigin/uBlock-issues/issues/759#issuecomment-546654501
@@ -209,12 +211,16 @@ const µBlock = {  // jshint ignore:line
     availableFilterLists: {},
     badLists: new Map(),
 
+    inMemoryFilters: [],
+    inMemoryFiltersCompiled: '',
+
     // https://github.com/uBlockOrigin/uBlock-issues/issues/974
     //   This can be used to defer filtering decision-making.
     readyToFilter: false,
 
     supportStats: {
-        launchToReadiness: '',
+        allReadyAfter: '',
+        maxAssetCacheWait: '0 ms',
     },
 
     pageStores: new Map(),
@@ -247,6 +253,7 @@ const µBlock = {  // jshint ignore:line
 
     liveBlockingProfiles: [],
     blockingProfileColorCache: new Map(),
+    uiAccentStylesheet: '',
 };
 
 µBlock.domainFromHostname = domainFromHostname;
