@@ -19,10 +19,13 @@
     Home: https://github.com/gorhill/uBlock
 */
 
-/* global uDom, faIconsInit */
+/* global faIconsInit */
 
 'use strict';
 
+import { i18n, i18n$ } from './i18n.js';
+import { dom, qs$ } from './dom.js';
+
 /******************************************************************************/
 
 (( ) => {
@@ -39,26 +42,26 @@ self.cloud = {
 
 /******************************************************************************/
 
-const widget = uDom.nodeFromId('cloudWidget');
+const widget = qs$('#cloudWidget');
 if ( widget === null ) { return; }
 
-self.cloud.datakey = widget.getAttribute('data-cloud-entry') || '';
+self.cloud.datakey = dom.attr(widget, 'data-cloud-entry') || '';
 if ( self.cloud.datakey === '' ) { return; }
 
 /******************************************************************************/
 
 const fetchStorageUsed = async function() {
-    let elem = widget.querySelector('#cloudCapacity');
-    if ( elem.classList.contains('hide') ) { return; }
+    let elem = qs$(widget, '#cloudCapacity');
+    if ( dom.cl.has(elem, 'hide') ) { return; }
     const result = await vAPI.messaging.send('cloudWidget', {
         what: 'cloudUsed',
         datakey: self.cloud.datakey,
     });
     if ( result instanceof Object === false ) {
-        elem.classList.add('hide');
+        dom.cl.add(elem, 'hide');
         return;
     }
-    const units = ' ' + vAPI.i18n('genericBytes');
+    const units = ' ' + i18n$('genericBytes');
     elem.title = result.max.toLocaleString() + units;
     const total = (result.total / result.max * 100).toFixed(1);
     elem = elem.firstElementChild;
@@ -73,7 +76,7 @@ const fetchStorageUsed = async function() {
 /******************************************************************************/
 
 const fetchCloudData = async function() {
-    const info = widget.querySelector('#cloudInfo');
+    const info = qs$(widget, '#cloudInfo');
 
     const entry = await vAPI.messaging.send('cloudWidget', {
         what: 'cloudPull',
@@ -82,16 +85,16 @@ const fetchCloudData = async function() {
 
     const hasData = entry instanceof Object;
     if ( hasData === false ) {
-        uDom.nodeFromId('cloudPull').setAttribute('disabled', '');
-        uDom.nodeFromId('cloudPullAndMerge').setAttribute('disabled', '');
+        dom.attr('#cloudPull', 'disabled', '');
+        dom.attr('#cloudPullAndMerge', 'disabled', '');
         info.textContent = '...\n...';
         return entry;
     }
 
     self.cloud.data = entry.data;
 
-    uDom.nodeFromId('cloudPull').removeAttribute('disabled');
-    uDom.nodeFromId('cloudPullAndMerge').removeAttribute('disabled');
+    dom.attr('#cloudPull', 'disabled', null);
+    dom.attr('#cloudPullAndMerge', 'disabled', null);
 
     const timeOptions = {
         weekday: 'short',
@@ -121,11 +124,8 @@ const pushData = async function() {
         data: self.cloud.onPush(),
     });
     const failed = typeof error === 'string';
-    document.getElementById('cloudPush')
-            .classList
-            .toggle('error', failed);
-    document.querySelector('#cloudError')
-            .textContent = failed ? error : '';
+    dom.cl.toggle('#cloudPush', 'error', failed);
+    dom.text('#cloudError', failed ? error : '');
     if ( failed ) { return; }
     fetchCloudData();
     fetchStorageUsed();
@@ -137,8 +137,8 @@ const pullData = function() {
     if ( typeof self.cloud.onPull === 'function' ) {
         self.cloud.onPull(self.cloud.data, false);
     }
-    document.getElementById('cloudPush').classList.remove('error');
-    document.querySelector('#cloudError').textContent = '';
+    dom.cl.remove('#cloudPush', 'error');
+    dom.text('#cloudError', '');
 };
 
 /******************************************************************************/
@@ -152,29 +152,29 @@ const pullAndMergeData = function() {
 /******************************************************************************/
 
 const openOptions = function() {
-    const input = uDom.nodeFromId('cloudDeviceName');
+    const input = qs$('#cloudDeviceName');
     input.value = self.cloud.options.deviceName;
-    input.setAttribute('placeholder', self.cloud.options.defaultDeviceName);
-    uDom.nodeFromId('cloudOptions').classList.add('show');
+    dom.attr(input, 'placeholder', self.cloud.options.defaultDeviceName);
+    dom.cl.add('#cloudOptions', 'show');
 };
 
 /******************************************************************************/
 
 const closeOptions = function(ev) {
-    const root = uDom.nodeFromId('cloudOptions');
+    const root = qs$('#cloudOptions');
     if ( ev.target !== root ) { return; }
-    root.classList.remove('show');
+    dom.cl.remove(root, 'show');
 };
 
 /******************************************************************************/
 
 const submitOptions = async function() {
-    uDom.nodeFromId('cloudOptions').classList.remove('show');
+    dom.cl.remove('#cloudOptions', 'show');
 
     const options = await vAPI.messaging.send('cloudWidget', {
         what: 'cloudSetOptions',
         options: {
-            deviceName: uDom.nodeFromId('cloudDeviceName').value
+            deviceName: qs$('#cloudDeviceName').value
         },
     });
     if ( options instanceof Object ) {
@@ -206,20 +206,20 @@ const onInitialize = function(options) {
 
         faIconsInit(widget);
 
-        vAPI.i18n.render(widget);
-        widget.classList.remove('hide');
+        i18n.render(widget);
+        dom.cl.remove(widget, 'hide');
 
-        uDom('#cloudPush').on('click', ( ) => { pushData(); });
-        uDom('#cloudPull').on('click', pullData);
-        uDom('#cloudPullAndMerge').on('click', pullAndMergeData);
-        uDom('#cloudCog').on('click', openOptions);
-        uDom('#cloudOptions').on('click', closeOptions);
-        uDom('#cloudOptionsSubmit').on('click', ( ) => { submitOptions(); });
+        dom.on('#cloudPush', 'click', ( ) => { pushData(); });
+        dom.on('#cloudPull', 'click', pullData);
+        dom.on('#cloudPullAndMerge', 'click', pullAndMergeData);
+        dom.on('#cloudCog', 'click', openOptions);
+        dom.on('#cloudOptions', 'click', closeOptions);
+        dom.on('#cloudOptionsSubmit', 'click', ( ) => { submitOptions(); });
 
         fetchCloudData().then(result => {
             if ( typeof result !== 'string' ) { return; }
-            document.getElementById('cloudPush').classList.add('error');
-            document.querySelector('#cloudError').textContent = result;
+            dom.cl.add('#cloudPush', 'error');
+            dom.text('#cloudError', result);
         });
         fetchStorageUsed();
     };
