@@ -34,6 +34,16 @@ const nonVisualElements = {
     style: true,
 };
 
+const regexFromString = (s, exact = false) => {
+    if ( s === '' ) { return /^/; }
+    const match = /^\/(.+)\/([i]?)$/.exec(s);
+    if ( match !== null ) {
+        return new RegExp(match[1], match[2] || undefined);
+    }
+    const reStr = s.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
+    return new RegExp(exact ? `^${reStr}$` : reStr);
+};
+
 // 'P' stands for 'Procedural'
 
 class PSelectorTask {
@@ -43,15 +53,19 @@ class PSelectorTask {
     }
 }
 
+class PSelectorVoidTask extends PSelectorTask {
+    constructor(task) {
+        super();
+        console.info(`uBO: :${task[0]}() operator does not exist`);
+    }
+    transpose() {
+    }
+}
 
 class PSelectorHasTextTask extends PSelectorTask {
     constructor(task) {
         super();
-        let arg0 = task[1], arg1;
-        if ( Array.isArray(task[1]) ) {
-            arg1 = arg0[1]; arg0 = arg0[0];
-        }
-        this.needle = new RegExp(arg0, arg1);
+        this.needle = regexFromString(task[1]);
     }
     transpose(node, output) {
         if ( this.needle.test(node.textContent) ) {
@@ -77,10 +91,27 @@ class PSelectorIfNotTask extends PSelectorIfTask {
 }
 PSelectorIfNotTask.prototype.target = false;
 
+class PSelectorMatchesAttrTask extends PSelectorTask {
+    constructor(task) {
+        super();
+        this.reAttr = regexFromString(task[1].attr, true);
+        this.reValue = regexFromString(task[1].value, true);
+    }
+    transpose(node, output) {
+        const attrs = node.getAttributeNames();
+        for ( const attr of attrs ) {
+            if ( this.reAttr.test(attr) === false ) { continue; }
+            if ( this.reValue.test(node.getAttribute(attr)) === false ) { continue; }
+            output.push(node);
+        }
+    }
+}
+
 class PSelectorMatchesCSSTask extends PSelectorTask {
     constructor(task) {
         super();
         this.name = task[1].name;
+        this.pseudo = task[1].pseudo ? `::${task[1].pseudo}` : null;
         let arg0 = task[1].value, arg1;
         if ( Array.isArray(arg0) ) {
             arg1 = arg0[1]; arg0 = arg0[0];
@@ -94,15 +125,50 @@ class PSelectorMatchesCSSTask extends PSelectorTask {
         }
     }
 }
-PSelectorMatchesCSSTask.prototype.pseudo = null;
-
 class PSelectorMatchesCSSAfterTask extends PSelectorMatchesCSSTask {
+    constructor(task) {
+        super(task);
+        this.pseudo = '::after';
+    }
 }
-PSelectorMatchesCSSAfterTask.prototype.pseudo = ':after';
 
 class PSelectorMatchesCSSBeforeTask extends PSelectorMatchesCSSTask {
+    constructor(task) {
+        super(task);
+        this.pseudo = '::before';
+    }
+}
+
+class PSelectorMatchesMediaTask extends PSelectorTask {
+    constructor(task) {
+        super();
+        this.mql = window.matchMedia(task[1]);
+        if ( this.mql.media === 'not all' ) { return; }
+        this.mql.addEventListener('change', ( ) => {
+            if ( typeof vAPI !== 'object' ) { return; }
+            if ( vAPI === null ) { return; }
+            const filterer = vAPI.domFilterer && vAPI.domFilterer.proceduralFilterer;
+            if ( filterer instanceof Object === false ) { return; }
+            filterer.onDOMChanged([ null ]);
+        });
+    }
+    transpose(node, output) {
+        if ( this.mql.matches === false ) { return; }
+        output.push(node);
+    }
+}
+
+class PSelectorMatchesPathTask extends PSelectorTask {
+    constructor(task) {
+        super();
+        this.needle = regexFromString(task[1]);
+    }
+    transpose(node, output) {
+        if ( this.needle.test(self.location.pathname + self.location.search) ) {
+            output.push(node);
+        }
+    }
 }
-PSelectorMatchesCSSBeforeTask.prototype.pseudo = ':before';
 
 class PSelectorMinTextLengthTask extends PSelectorTask {
     constructor(task) {
@@ -116,22 +182,6 @@ class PSelectorMinTextLengthTask extends PSelectorTask {
     }
 }
 
-class PSelectorMatchesPathTask extends PSelectorTask {
-    constructor(task) {
-        super();
-        let arg0 = task[1], arg1;
-        if ( Array.isArray(task[1]) ) {
-            arg1 = arg0[1]; arg0 = arg0[0];
-        }
-        this.needle = new RegExp(arg0, arg1);
-    }
-    transpose(node, output) {
-        if ( this.needle.test(self.location.pathname + self.location.search) ) {
-            output.push(node);
-        }
-    }
-}
-
 class PSelectorOthersTask extends PSelectorTask {
     constructor() {
         super();
@@ -200,12 +250,18 @@ class PSelectorSpathTask extends PSelectorTask {
             this.spath = `:scope ${this.spath.trim()}`;
         }
     }
-    qsa(node) {
-        if ( this.nth === false ) {
-            return node.querySelectorAll(this.spath);
+    transpose(node, output) {
+        const nodes = this.nth
+            ? PSelectorSpathTask.qsa(node, this.spath)
+            : node.querySelectorAll(this.spath);
+        for ( const node of nodes ) {
+            output.push(node);
         }
+    }
+    // Helper method for other operators.
+    static qsa(node, selector) {
         const parent = node.parentElement;
-        if ( parent === null ) { return; }
+        if ( parent === null ) { return []; }
         let pos = 1;
         for (;;) {
             node = node.previousElementSibling;
@@ -213,16 +269,9 @@ class PSelectorSpathTask extends PSelectorTask {
             pos += 1;
         }
         return parent.querySelectorAll(
-            `:scope > :nth-child(${pos})${this.spath}`
+            `:scope > :nth-child(${pos})${selector}`
         );
     }
-    transpose(node, output) {
-        const nodes = this.qsa(node);
-        if ( nodes === undefined ) { return; }
-        for ( const node of nodes ) {
-            output.push(node);
-        }
-    }
 }
 
 class PSelectorUpwardTask extends PSelectorTask {
@@ -313,42 +362,23 @@ class PSelectorXpathTask extends PSelectorTask {
 
 class PSelector {
     constructor(o) {
-        if ( PSelector.prototype.operatorToTaskMap === undefined ) {
-            PSelector.prototype.operatorToTaskMap = new Map([
-                [ ':has', PSelectorIfTask ],
-                [ ':has-text', PSelectorHasTextTask ],
-                [ ':if', PSelectorIfTask ],
-                [ ':if-not', PSelectorIfNotTask ],
-                [ ':matches-css', PSelectorMatchesCSSTask ],
-                [ ':matches-css-after', PSelectorMatchesCSSAfterTask ],
-                [ ':matches-css-before', PSelectorMatchesCSSBeforeTask ],
-                [ ':matches-path', PSelectorMatchesPathTask ],
-                [ ':min-text-length', PSelectorMinTextLengthTask ],
-                [ ':not', PSelectorIfNotTask ],
-                [ ':nth-ancestor', PSelectorUpwardTask ],
-                [ ':others', PSelectorOthersTask ],
-                [ ':spath', PSelectorSpathTask ],
-                [ ':upward', PSelectorUpwardTask ],
-                [ ':watch-attr', PSelectorWatchAttrs ],
-                [ ':xpath', PSelectorXpathTask ],
-            ]);
-        }
         this.raw = o.raw;
         this.selector = o.selector;
         this.tasks = [];
         const tasks = [];
         if ( Array.isArray(o.tasks) === false ) { return; }
         for ( const task of o.tasks ) {
-            const ctor = this.operatorToTaskMap.get(task[0]);
-            if ( ctor === undefined ) { return; }
+            const ctor = this.operatorToTaskMap.get(task[0]) || PSelectorVoidTask;
             tasks.push(new ctor(task));
         }
-        // Initialize only after all tasks have been successfully instantiated
         this.tasks = tasks;
     }
     prime(input) {
         const root = input || document;
         if ( this.selector === '' ) { return [ root ]; }
+        if ( input !== document && /^ ?[>+~]/.test(this.selector) ) {
+            return Array.from(PSelectorSpathTask.qsa(input, this.selector));
+        }
         return Array.from(root.querySelectorAll(this.selector));
     }
     exec(input) {
@@ -384,16 +414,41 @@ class PSelector {
         return false;
     }
 }
-PSelector.prototype.operatorToTaskMap = undefined;
+PSelector.prototype.operatorToTaskMap = new Map([
+    [ 'has', PSelectorIfTask ],
+    [ 'has-text', PSelectorHasTextTask ],
+    [ 'if', PSelectorIfTask ],
+    [ 'if-not', PSelectorIfNotTask ],
+    [ 'matches-attr', PSelectorMatchesAttrTask ],
+    [ 'matches-css', PSelectorMatchesCSSTask ],
+    [ 'matches-css-after', PSelectorMatchesCSSAfterTask ],
+    [ 'matches-css-before', PSelectorMatchesCSSBeforeTask ],
+    [ 'matches-media', PSelectorMatchesMediaTask ],
+    [ 'matches-path', PSelectorMatchesPathTask ],
+    [ 'min-text-length', PSelectorMinTextLengthTask ],
+    [ 'not', PSelectorIfNotTask ],
+    [ 'others', PSelectorOthersTask ],
+    [ 'spath', PSelectorSpathTask ],
+    [ 'upward', PSelectorUpwardTask ],
+    [ 'watch-attr', PSelectorWatchAttrs ],
+    [ 'xpath', PSelectorXpathTask ],
+]);
 
 class PSelectorRoot extends PSelector {
-    constructor(o, styleToken) {
+    constructor(o) {
         super(o);
         this.budget = 200; // I arbitrary picked a 1/5 second
         this.raw = o.raw;
         this.cost = 0;
         this.lastAllowanceTime = 0;
-        this.styleToken = styleToken;
+        this.action = o.action;
+    }
+    prime(input) {
+        try {
+            return super.prime(input);
+        } catch (ex) {
+        }
+        return [];
     }
 }
 PSelectorRoot.prototype.hit = false;
@@ -401,8 +456,6 @@ PSelectorRoot.prototype.hit = false;
 class ProceduralFilterer {
     constructor(domFilterer) {
         this.domFilterer = domFilterer;
-        this.domIsReady = false;
-        this.domIsWatched = false;
         this.mustApplySelectors = false;
         this.selectors = new Map();
         this.masterToken = vAPI.randomToken();
@@ -415,19 +468,11 @@ class ProceduralFilterer {
 
     addProceduralSelectors(selectors) {
         const addedSelectors = [];
-        let mustCommit = this.domIsWatched;
+        let mustCommit = false;
         for ( const selector of selectors ) {
             if ( this.selectors.has(selector.raw) ) { continue; }
-            let style, styleToken;
-            if ( selector.action === undefined ) {
-                style = vAPI.hideStyle;
-            } else if ( selector.action[0] === ':style' ) {
-                style = selector.action[1];
-            }
-            if ( style !== undefined ) {
-                styleToken = this.styleTokenFromStyle(style);
-            }
-            const pselector = new PSelectorRoot(selector, styleToken);
+            const pselector = new PSelectorRoot(selector);
+            this.primeProceduralSelector(pselector);
             this.selectors.set(selector.raw, pselector);
             addedSelectors.push(pselector);
             mustCommit = true;
@@ -442,15 +487,22 @@ class ProceduralFilterer {
         }
     }
 
-    commitNow() {
-        if ( this.selectors.size === 0 || this.domIsReady === false ) {
-            return;
+    // This allows to perform potentially expensive initialization steps
+    // before the filters are ready to be applied.
+    primeProceduralSelector(pselector) {
+        if ( pselector.action === undefined ) {
+            this.styleTokenFromStyle(vAPI.hideStyle);
+        } else if ( pselector.action[0] === 'style' ) {
+            this.styleTokenFromStyle(pselector.action[1]);
         }
+        return pselector;
+    }
+
+    commitNow() {
+        if ( this.selectors.size === 0 ) { return; }
 
         this.mustApplySelectors = false;
 
-        //console.time('procedural selectors/dom layout changed');
-
         // https://github.com/uBlockOrigin/uBlock-issues/issues/341
         //   Be ready to unhide nodes which no longer matches any of
         //   the procedural selectors.
@@ -477,11 +529,10 @@ class ProceduralFilterer {
             t0 = t1;
             if ( nodes.length === 0 ) { continue; }
             pselector.hit = true;
-            this.styleNodes(nodes, pselector.styleToken);
+            this.processNodes(nodes, pselector.action);
         }
 
-        this.unstyleNodes(toUnstyle);
-        //console.timeEnd('procedural selectors/dom layout changed');
+        this.unprocessNodes(toUnstyle);
     }
 
     styleTokenFromStyle(style) {
@@ -497,25 +548,60 @@ class ProceduralFilterer {
         return styleToken;
     }
 
-    styleNodes(nodes, styleToken) {
-        if ( styleToken === undefined ) {
+    processNodes(nodes, action) {
+        const op = action && action[0] || '';
+        const arg = op !== '' ? action[1] : '';
+        switch ( op ) {
+        case '':
+            /* fall through */
+        case 'style': {
+            const styleToken = this.styleTokenFromStyle(
+                arg === '' ? vAPI.hideStyle : arg
+            );
             for ( const node of nodes ) {
-                node.textContent = '';
-                node.remove();
+                node.setAttribute(this.masterToken, '');
+                node.setAttribute(styleToken, '');
+                this.styledNodes.add(node);
             }
-            return;
+            break;
         }
-        for ( const node of nodes ) {
-            node.setAttribute(this.masterToken, '');
-            node.setAttribute(styleToken, '');
-            this.styledNodes.add(node);
+        case 'remove': {
+            for ( const node of nodes ) {
+                node.remove();
+                node.textContent = '';
+            }
+            break;
+        }
+        case 'remove-attr': {
+            const reAttr = regexFromString(arg, true);
+            for ( const node of nodes ) {
+                for ( const name of node.getAttributeNames() ) {
+                    if ( reAttr.test(name) === false ) { continue; }
+                    node.removeAttribute(name);
+                }
+            }
+            break;
+        }
+        case 'remove-class': {
+            const reClass = regexFromString(arg, true);
+            for ( const node of nodes ) {
+                const cl = node.classList;
+                for ( const name of cl.values() ) {
+                    if ( reClass.test(name) === false ) { continue; }
+                    cl.remove(name);
+                }
+            }
+            break;
+        }
+        default:
+            break;
         }
     }
 
     // TODO: Current assumption is one style per hit element. Could be an
     //       issue if an element has multiple styling and one styling is
-    //       brough back. Possibly too rare to care about this for now.
-    unstyleNodes(nodes) {
+    //       brought back. Possibly too rare to care about this for now.
+    unprocessNodes(nodes) {
         for ( const node of nodes ) {
             if ( this.styledNodes.has(node) ) { continue; }
             node.removeAttribute(this.masterToken);
@@ -523,12 +609,12 @@ class ProceduralFilterer {
     }
 
     createProceduralFilter(o) {
-        return new PSelectorRoot(o);
+        return this.primeProceduralSelector(
+            new PSelectorRoot(typeof o === 'string' ? JSON.parse(o) : o)
+        );
     }
 
     onDOMCreated() {
-        this.domIsReady = true;
-        this.domFilterer.commit();
     }
 
     onDOMChanged(addedNodes, removedNodes) {
