@@ -27,6 +27,7 @@ import staticNetFilteringEngine from './static-net-filtering.js';
 import µb from './background.js';
 import { CompiledListWriter } from './static-filtering-io.js';
 import { StaticFilteringParser } from './static-filtering-parser.js';
+import { i18n$ } from './i18n.js';
 
 import {
     domainFromHostname,
@@ -110,7 +111,7 @@ const initWorker = function() {
         entries.set(listKey, {
             title: listKey !== µb.userFiltersPath ?
                 entry.title :
-                vAPI.i18n('1pPageName'),
+                i18n$('1pPageName'),
             supportURL: entry.supportURL || ''
         });
     }
@@ -133,7 +134,9 @@ const fromNetFilter = async function(rawFilter) {
     if ( typeof rawFilter !== 'string' || rawFilter === '' ) { return; }
 
     const writer = new CompiledListWriter();
-    const parser = new StaticFilteringParser();
+    const parser = new StaticFilteringParser({
+        nativeCssHas: vAPI.webextFlavor.env.includes('native_css_has'),
+    });
     parser.setMaxTokenLength(staticNetFilteringEngine.MAX_TOKEN_LENGTH);
     parser.analyze(rawFilter);
 
@@ -155,7 +158,7 @@ const fromNetFilter = async function(rawFilter) {
     });
 };
 
-const fromCosmeticFilter = async function(details) {
+const fromExtendedFilter = async function(details) {
     if (
         typeof details.rawFilter !== 'string' ||
         details.rawFilter === ''
@@ -169,7 +172,7 @@ const fromCosmeticFilter = async function(details) {
     const hostname = hostnameFromURI(details.url);
 
     worker.postMessage({
-        what: 'fromCosmeticFilter',
+        what: 'fromExtendedFilter',
         id: id,
         domain: domainFromHostname(hostname),
         hostname: hostname,
@@ -203,7 +206,7 @@ const resetLists = function() {
 
 const staticFilteringReverseLookup = {
     fromNetFilter,
-    fromCosmeticFilter,
+    fromExtendedFilter,
     resetLists,
     shutdown: stopWorker
 };
