@@ -28,10 +28,7 @@ import µb from './background.js';
 import { redirectEngine } from './redirect-engine.js';
 import { sessionFirewall } from './filtering-engines.js';
 
-import {
-    StaticExtFilteringHostnameDB,
-    StaticExtFilteringSessionDB,
-} from './static-ext-filtering-db.js';
+import { StaticExtFilteringHostnameDB } from './static-ext-filtering-db.js';
 
 import {
     domainFromHostname,
@@ -46,7 +43,6 @@ const scriptletCache = new µb.MRUCache(32);
 const reEscapeScriptArg = /[\\'"]/g;
 
 const scriptletDB = new StaticExtFilteringHostnameDB(1);
-const sessionScriptletDB = new StaticExtFilteringSessionDB();
 
 let acceptedCount = 0;
 let discardedCount = 0;
@@ -88,36 +84,23 @@ const scriptletFilteringEngine = {
 const contentscriptCode = (( ) => {
     const parts = [
         '(',
-        function(hostname, scriptlets) {
+        function(injector, hostname, scriptlets) {
+            const doc = document;
             if (
-                document.location === null ||
-                hostname !== document.location.hostname
+                doc.location === null ||
+                hostname !== doc.location.hostname ||
+                typeof self.uBO_scriptletsInjected === 'boolean'
             ) {
                 return;
             }
-            const injectScriptlets = function(d) {
-                let script;
-                try {
-                    script = d.createElement('script');
-                    script.appendChild(d.createTextNode(
-                        decodeURIComponent(scriptlets))
-                    );
-                    (d.head || d.documentElement).appendChild(script);
-                } catch (ex) {
-                }
-                if ( script ) {
-                    if ( script.parentNode ) {
-                        script.parentNode.removeChild(script);
-                    }
-                    script.textContent = '';
-                }
-            };
-            injectScriptlets(document);
+            injector(doc, decodeURIComponent(scriptlets));
+            if ( typeof self.uBO_scriptletsInjected === 'boolean' ) { return 0; }
         }.toString(),
         ')(',
+            vAPI.scriptletsInjector, ', ',
             '"', 'hostname-slot', '", ',
             '"', 'scriptlets-slot', '"',
-        '); void 0;',
+        ');',
     ];
     return {
         parts: parts,
@@ -125,8 +108,7 @@ const contentscriptCode = (( ) => {
         scriptletsSlot: parts.indexOf('scriptlets-slot'),
         assemble: function(hostname, scriptlets) {
             this.parts[this.hostnameSlot] = hostname;
-            this.parts[this.scriptletsSlot] =
-                encodeURIComponent(scriptlets);
+            this.parts[this.scriptletsSlot] = encodeURIComponent(scriptlets);
             return this.parts.join('');
         }
     };
@@ -178,10 +160,7 @@ const lookupScriptlet = function(rawToken, reng, toInject) {
         } else {
             token = `${token}.js`;
         }
-        content = reng.resourceContentFromName(
-            token,
-            'application/javascript'
-        );
+        content = reng.resourceContentFromName(token, 'text/javascript');
         if ( !content ) { return; }
         if ( args ) {
             content = patchScriptlet(content, args);
@@ -221,18 +200,15 @@ const patchScriptlet = function(content, args) {
     return content;
 };
 
-const logOne = function(isException, token, details) {
+const logOne = function(tabId, url, filter) {
     µb.filteringContext
         .duplicate()
-        .fromTabId(details.tabId)
+        .fromTabId(tabId)
         .setRealm('extended')
         .setType('dom')
-        .setURL(details.url)
-        .setDocOriginFromURL(details.url)
-        .setFilter({
-            source: 'extended',
-            raw: (isException ? '#@#' : '##') + `+js(${token})`
-        })
+        .setURL(url)
+        .setDocOriginFromURL(url)
+        .setFilter({ source: 'extended', raw: filter })
         .toLogger();
 };
 
@@ -282,13 +258,6 @@ scriptletFilteringEngine.compile = function(parser, writer) {
     }
 };
 
-scriptletFilteringEngine.compileTemporary = function(parser) {
-    return {
-        session: sessionScriptletDB,
-        selector: parser.result.compiled,
-    };
-};
-
 // 01234567890123456789
 // +js(token[, arg[, ...]])
 //     ^                  ^
@@ -311,15 +280,11 @@ scriptletFilteringEngine.fromCompiledContent = function(reader) {
     }
 };
 
-scriptletFilteringEngine.getSession = function() {
-    return sessionScriptletDB;
-};
-
 const $scriptlets = new Set();
 const $exceptions = new Set();
 const $scriptletToCodeMap = new Map();
 
-scriptletFilteringEngine.retrieve = function(request) {
+scriptletFilteringEngine.retrieve = function(request, options = {}) {
     if ( scriptletDB.size === 0 ) { return; }
 
     const hostname = request.hostname;
@@ -327,9 +292,6 @@ scriptletFilteringEngine.retrieve = function(request) {
     $scriptlets.clear();
     $exceptions.clear();
 
-    if ( sessionScriptletDB.isNotEmpty ) {
-        sessionScriptletDB.retrieve([ null, $exceptions ]);
-    }
     scriptletDB.retrieve(hostname, [ $scriptlets, $exceptions ]);
     const entity = request.entity !== ''
         ? `${hostname.slice(0, -request.domain.length)}${request.entity}`
@@ -346,29 +308,38 @@ scriptletFilteringEngine.retrieve = function(request) {
         return;
     }
 
+    const mustLog = Array.isArray(options.logEntries);
+
     // Wholly disable scriptlet injection?
     if ( $exceptions.has('') ) {
-        if ( logger.enabled ) {
-            logOne(true, '', request);
+        if ( mustLog ) {
+            logOne(request.tabId, request.url, '#@#+js()');
         }
         return;
     }
 
     $scriptletToCodeMap.clear();
-    for ( const rawToken of $scriptlets ) {
-        lookupScriptlet(rawToken, redirectEngine, $scriptletToCodeMap);
+    for ( const token of $scriptlets ) {
+        lookupScriptlet(token, redirectEngine, $scriptletToCodeMap);
     }
     if ( $scriptletToCodeMap.size === 0 ) { return; }
 
     // Return an array of scriptlets, and log results if needed.
     const out = [];
-    for ( const [ rawToken, code ] of $scriptletToCodeMap ) {
-        const isException = $exceptions.has(rawToken);
+    for ( const [ token, code ] of $scriptletToCodeMap ) {
+        const isException = $exceptions.has(token);
         if ( isException === false ) {
             out.push(code);
         }
-        if ( logger.enabled ) {
-            logOne(isException, rawToken, request);
+        if ( mustLog === false ) { continue; }
+        if ( isException ) {
+            logOne(request.tabId, request.url, `#@#+js(${token})`);
+        } else {
+            options.logEntries.push({
+                token: `##+js(${token})`,
+                tabId: request.tabId,
+                url: request.url,
+            });
         }
     }
 
@@ -411,18 +382,30 @@ scriptletFilteringEngine.injectNow = function(details) {
     };
     request.domain = domainFromHostname(request.hostname);
     request.entity = entityFromDomain(request.domain);
-    const scriptlets = this.retrieve(request);
+    const logEntries = logger.enabled ? [] : undefined;
+    const scriptlets = this.retrieve(request, { logEntries });
     if ( scriptlets === undefined ) { return; }
     let code = contentscriptCode.assemble(request.hostname, scriptlets);
     if ( µb.hiddenSettings.debugScriptletInjector ) {
         code = 'debugger;\n' + code;
     }
-    vAPI.tabs.executeScript(details.tabId, {
+    const promise = vAPI.tabs.executeScript(details.tabId, {
         code,
         frameId: details.frameId,
         matchAboutBlank: true,
         runAt: 'document_start',
     });
+    if ( logEntries !== undefined ) {
+        promise.then(results => {
+            if ( Array.isArray(results) === false || results[0] !== 0 ) {
+                return;
+            }
+            for ( const entry of logEntries ) {
+                logOne(entry.tabId, entry.url, entry.token);
+            }
+        });
+    }
+    return scriptlets;
 };
 
 scriptletFilteringEngine.toSelfie = function() {
