@@ -40,8 +40,6 @@ const simpleDeclarativeSet = new Set();
 let simpleDeclarativeStr;
 const complexDeclarativeSet = new Set();
 let complexDeclarativeStr;
-const declarativeStyleDict = new Map();
-let declarativeStyleStr;
 const proceduralDict = new Map();
 const exceptionDict = new Map();
 let exceptionStr;
@@ -53,18 +51,37 @@ const loggedSelectors = new Set();
 
 const rePseudoElements = /:(?::?after|:?before|:[a-z-]+)$/;
 
+const hasSelector = function(selector, context = document) {
+    try {
+        return context.querySelector(selector) !== null;
+    }
+    catch(ex) {
+    }
+    return false;
+};
+
 const safeMatchSelector = function(selector, context) {
     const safeSelector = rePseudoElements.test(selector)
         ? selector.replace(rePseudoElements, '')
         : selector;
-    return context.matches(safeSelector);
+    try {
+        return context.matches(safeSelector);
+    }
+    catch(ex) {
+    }
+    return false;
 };
 
 const safeQuerySelector = function(selector, context = document) {
     const safeSelector = rePseudoElements.test(selector)
         ? selector.replace(rePseudoElements, '')
         : selector;
-    return context.querySelector(safeSelector);
+    try {
+        return context.querySelector(safeSelector);
+    }
+    catch(ex) {
+    }
+    return null;
 };
 
 const safeGroupSelectors = function(selectors) {
@@ -87,7 +104,7 @@ const processDeclarativeSimple = function(node, out) {
     }
     if (
         (node === document || node.matches(simpleDeclarativeStr) === false) &&
-        (node.querySelector(simpleDeclarativeStr) === null)
+        (hasSelector(simpleDeclarativeStr, node) === false)
     ) {
         return;
     }
@@ -112,7 +129,7 @@ const processDeclarativeComplex = function(out) {
     if ( complexDeclarativeStr === undefined ) {
         complexDeclarativeStr = safeGroupSelectors(complexDeclarativeSet);
     }
-    if ( document.querySelector(complexDeclarativeStr) === null ) { return; }
+    if ( hasSelector(complexDeclarativeStr) === false ) { return; }
     for ( const selector of complexDeclarativeSet ) {
         if ( safeQuerySelector(selector) === null ) { continue; }
         out.push(`##${selector}`);
@@ -124,30 +141,12 @@ const processDeclarativeComplex = function(out) {
 
 /******************************************************************************/
 
-const processDeclarativeStyle = function(out) {
-    if ( declarativeStyleDict.size === 0 ) { return; }
-    if ( declarativeStyleStr === undefined ) {
-        declarativeStyleStr = safeGroupSelectors(declarativeStyleDict.keys());
-    }
-    if ( document.querySelector(declarativeStyleStr) === null ) { return; }
-    for ( const selector of declarativeStyleDict.keys() ) {
-        if ( safeQuerySelector(selector) === null ) { continue; }
-        for ( const style of declarativeStyleDict.get(selector) ) {
-            const raw = `##${selector}:style(${style})`;
-            out.push(raw);
-            loggedSelectors.add(raw);
-        }
-        declarativeStyleDict.delete(selector);
-        declarativeStyleStr = undefined;
-    }
-};
-
-/******************************************************************************/
-
 const processProcedural = function(out) {
     if ( proceduralDict.size === 0 ) { return; }
     for ( const [ raw, pselector ] of proceduralDict ) {
-        if ( pselector.hit === false ) { continue; }
+        if ( pselector.hit === false && pselector.exec().length === 0 ) {
+            continue;
+        }
         out.push(`##${raw}`);
         proceduralDict.delete(raw);
     }
@@ -160,7 +159,7 @@ const processExceptions = function(out) {
     if ( exceptionStr === undefined ) {
         exceptionStr = safeGroupSelectors(exceptionDict.keys());
     }
-    if ( document.querySelector(exceptionStr) === null ) { return; }
+    if ( hasSelector(exceptionStr) === false ) { return; }
     for ( const [ selector, raw ] of exceptionDict ) {
         if ( safeQuerySelector(selector) === null ) { continue; }
         out.push(`#@#${raw}`);
@@ -201,7 +200,6 @@ const processTimer = new vAPI.SafeAnimationFrame(( ) => {
     }
 
     processDeclarativeComplex(toLog);
-    processDeclarativeStyle(toLog);
     processProcedural(toLog);
     processExceptions(toLog);
     processProceduralExceptions(toLog);
@@ -240,18 +238,8 @@ const attributeObserver = new MutationObserver(mutations => {
 const handlers = {
     onFiltersetChanged: function(changes) {
         //console.time('dom logger/filterset changed');
-        for ( const entry of (changes.declarative || []) ) {
-            for ( let selector of entry[0].split(',\n') ) {
-                if ( entry[1] !== 'display:none!important;' ) {
-                    declarativeStyleStr = undefined;
-                    const styles = declarativeStyleDict.get(selector);
-                    if ( styles === undefined ) {
-                        declarativeStyleDict.set(selector, [ entry[1] ]);
-                        continue;
-                    }
-                    styles.push(entry[1]);
-                    continue;
-                }
+        for ( const block of (changes.declarative || []) ) {
+            for ( const selector of block.split(',\n') ) {
                 if ( loggedSelectors.has(selector) ) { continue; }
                 if ( reHasCSSCombinators.test(selector) ) {
                     complexDeclarativeSet.add(selector);
@@ -278,7 +266,11 @@ const handlers = {
                     continue;
                 }
                 const details = JSON.parse(selector);
-                if ( details.action === 'style' ) {
+                if (
+                    details.action !== undefined &&
+                    details.tasks === undefined &&
+                    details.action[0] === ':style'
+                ) {
                     exceptionDict.set(details.selector, details.raw);
                     continue;
                 }
