@@ -19,6 +19,8 @@
     Home: https://github.com/gorhill/uBlock
 */
 
+/* globals browser */
+
 'use strict';
 
 /******************************************************************************/
@@ -134,6 +136,9 @@ const initializeTabs = async function() {
 /******************************************************************************/
 
 // To bring older versions up to date
+//
+// https://www.reddit.com/r/uBlockOrigin/comments/s7c9go/
+//   Abort suspending network requests when uBO is merely being installed.
 
 const onVersionReady = function(lastVersion) {
     if ( lastVersion === vAPI.app.version ) { return; }
@@ -141,7 +146,12 @@ const onVersionReady = function(lastVersion) {
     vAPI.storage.set({ version: vAPI.app.version });
 
     const lastVersionInt = vAPI.app.intFromVersion(lastVersion);
-    if ( lastVersionInt === 0 ) { return; }
+
+    // Special case: first installation
+    if ( lastVersionInt === 0 ) {
+        vAPI.net.unsuspend({ all: true, discard: true });
+        return;
+    }
 
     // Since built-in resources may have changed since last version, we
     // force a reload of all resources.
@@ -192,6 +202,23 @@ const onNetWhitelistReady = function(netWhitelistRaw, adminExtra) {
 // User settings are in memory
 
 const onUserSettingsReady = function(fetched) {
+    // Terminate suspended state?
+    const tnow = Date.now() - vAPI.T0;
+    if (
+        vAPI.Net.canSuspend() &&
+        fetched.suspendUntilListsAreLoaded === false
+    ) {
+        vAPI.net.unsuspend({ all: true, discard: true });
+        ubolog(`Unsuspend network activity listener at ${tnow} ms`);
+        µb.supportStats.unsuspendAfter = `${tnow} ms`;
+    } else if (
+        vAPI.Net.canSuspend() === false &&
+        fetched.suspendUntilListsAreLoaded
+    ) {
+        vAPI.net.suspend();
+        ubolog(`Suspend network activity listener at ${tnow} ms`);
+    }
+
     // `externalLists` will be deprecated in some future, it is kept around
     // for forward compatibility purpose, and should reflect the content of
     // `importedLists`.
@@ -282,13 +309,6 @@ const onHiddenSettingsReady = async function() {
         ubolog(`Override default webext flavor with ${tokens}`);
     }
 
-    // Maybe override current network listener suspend state
-    if ( µb.hiddenSettings.suspendTabsUntilReady === 'no' ) {
-        vAPI.net.unsuspend(true);
-    } else if ( µb.hiddenSettings.suspendTabsUntilReady === 'yes' ) {
-        vAPI.net.suspend();
-    }
-
     // Maybe disable WebAssembly
     if ( vAPI.canWASM && µb.hiddenSettings.disableWebAssembly !== true ) {
         const wasmModuleFetcher = function(path) {
@@ -475,25 +495,6 @@ io.addObserver(µb.assetObserver.bind(µb));
 // active tab.
 contextMenu.update();
 
-// Maybe install non-default popup document, or automatically select
-// default UI according to platform.
-if (
-    browser.browserAction instanceof Object &&
-    browser.browserAction.setPopup instanceof Function
-) {
-    const env = vAPI.webextFlavor;
-    if (
-        µb.hiddenSettings.uiFlavor === 'classic' || (
-            µb.hiddenSettings.uiFlavor === 'unset' && (
-                env.soup.has('chromium') && env.major < 66 ||
-                env.soup.has('firefox') && env.major < 68
-            )
-        )
-    ) {
-        browser.browserAction.setPopup({ popup: 'popup.html' });
-    }
-}
-
 // https://github.com/uBlockOrigin/uBlock-issues/issues/717
 //   Prevent the extension from being restarted mid-session.
 browser.runtime.onUpdateAvailable.addListener(details => {
@@ -506,11 +507,11 @@ browser.runtime.onUpdateAvailable.addListener(details => {
     }
 });
 
-µb.supportStats.launchToReadiness = `${Date.now() - vAPI.T0} ms`;
+µb.supportStats.allReadyAfter = `${Date.now() - vAPI.T0} ms`;
 if ( selfieIsValid ) {
-    µb.supportStats.launchToReadiness += ' (selfie)';
+    µb.supportStats.allReadyAfter += ' (selfie)';
 }
-ubolog(`All ready ${µb.supportStats.launchToReadiness} ms after launch`);
+ubolog(`All ready ${µb.supportStats.allReadyAfter} ms after launch`);
 
 // <<<<< end of private scope
 })();
