@@ -30,6 +30,7 @@ import staticNetFilteringEngine from './static-net-filtering.js';
 import µb from './background.js';
 import webext from './webext.js';
 import { PageStore } from './pagestore.js';
+import { i18n$ } from './i18n.js';
 
 import {
     sessionFirewall,
@@ -40,7 +41,6 @@ import {
 import {
     domainFromHostname,
     hostnameFromURI,
-    isNetworkURI,
     originFromURI,
 } from './uri-utils.js';
 
@@ -339,14 +339,9 @@ const onPopupUpdated = (( ) => {
             return;
         }
 
-        // If the page URL is that of our "blocked page" URL, extract the URL
+        // If the page URL is that of our document-blocked URL, extract the URL
         // of the page which was blocked.
-        if ( targetURL.startsWith(vAPI.getURL('document-blocked.html')) ) {
-            const matches = /details=([^&]+)/.exec(targetURL);
-            if ( matches !== null ) {
-                targetURL = JSON.parse(decodeURIComponent(matches[1])).url;
-            }
-        }
+        targetURL = µb.pageURLFromMaybeDocumentBlockedURL(targetURL);
 
         // MUST be reset before code below is called.
         const fctxt = µb.filteringContext.duplicate();
@@ -683,6 +678,9 @@ housekeep itself.
 
     // Update just force all properties to be updated to match the most recent
     // root URL.
+    // https://github.com/uBlockOrigin/uBlock-issues/issues/1954
+    //   In case of document-blocked page, use the blocked page URL as the
+    //   context.
     TabContext.prototype.update = function() {
         this.netFilteringReadTime = 0;
         if ( this.stack.length === 0 ) {
@@ -694,7 +692,7 @@ housekeep itself.
             return;
         }
         const stackEntry = this.stack[this.stack.length - 1];
-        this.rawURL = stackEntry.url;
+        this.rawURL = µb.pageURLFromMaybeDocumentBlockedURL(stackEntry.url);
         this.normalURL = µb.normalizeTabURL(this.tabId, this.rawURL);
         this.origin = originFromURI(this.normalURL);
         this.rootHostname = hostnameFromURI(this.origin);
@@ -918,6 +916,10 @@ vAPI.Tabs = class extends vAPI.Tabs {
     //   For non-network URIs, defer scriptlet injection to content script. The
     //   reason for this is that we need the effective URL and this information
     //   is not available at this point.
+    //
+    // https://github.com/uBlockOrigin/uBlock-issues/issues/2343
+    //   uBO's isolated world in Firefox just does not work as expected at
+    //   point, so we have to wait before injecting scriptlets.
     onNavigation(details) {
         super.onNavigation(details);
         const { frameId, tabId, url } = details;
@@ -931,11 +933,7 @@ vAPI.Tabs = class extends vAPI.Tabs {
         const pageStore = µb.pageStoreFromTabId(tabId);
         if ( pageStore === null ) { return; }
         pageStore.setFrameURL(details);
-        if (
-            µb.canInjectScriptletsNow &&
-            isNetworkURI(url) &&
-            pageStore.getNetFilteringSwitch()
-        ) {
+        if ( pageStore.getNetFilteringSwitch() ) {
             scriptletFilteringEngine.injectNow(details);
         }
     }
@@ -1054,7 +1052,7 @@ vAPI.tabs = new vAPI.Tabs();
     };
     const pageStore = new NoPageStore(vAPI.noTabId);
     µb.pageStores.set(pageStore.tabId, pageStore);
-    pageStore.title = vAPI.i18n('logBehindTheScene');
+    pageStore.title = i18n$('logBehindTheScene');
 }
 
 /******************************************************************************/
